============
Installation
============

To get the latest released version, just use pip::

    $ pip install vittles

However, ``vittles`` is under active development, and you may want to install
a newer version from github::

    $ pip install git+git://github.com/rgiordan/vittles
